TEXAS FIRE ALARM EXAM PREPARATION VERSION 1 COMPLETE
QUESTIONS AND DETAILED SOLUTIONS LATEST UPDATE THIS
YEAR JUST RELEASED
Question 1: When must the three installation inspections be
performed?
Answer:
1- At the completion of the device back box but prior to #2 - 2- At the completion of
the device cable installation but prior to #3 - 3- At the completion of the device
installation but prior to activation
Question 2: What is the purpose of fire alarm plans and record
drawings tag?
Answer:
To certify that the plan or finished drawing of a fire system meets all codes and
standards
Question 3: What five things should it say on the installation label?
Answer:
DO NOT REMOVE BY ORDER OF THE TEXAS FIRE MARSHALL
-INSTALLATION RECORD -The firms name address telephone and registration
number -Installation date and licensee signature and license number -The name of
whoever planned the system
Question 4: What five things should it say on the RESIDENTIAL
installation label?
Answer:
DO NOT REMOVE BY ORDER OF THE TEXAS FIRE MARSHALL
INSTALLATION RECORD -The firm's name address telephone and registration
number -Installation date and licensee signature and license number -An
inscription certifying the install meets code
Question 5: When and where must the installation labels be
placed?
,Answer:
Inside the control panel cover or in a permanent location
Question 6: When must a service label be used?
Answer:
After any service that has corrected and issue that was noted on a yellow or red
label
Question 7: How long must a service label stay in place?
Answer:
Two years. An agent of the Fire Marshall may remove it at any time.
Question 8: What six things must be listed on a Service Label?
Answer:
DO NOT REMOVE BY ORDER OF THE TEXAS FIRE MARSHALL SERVICE
RECORD -The firm's name address telephone and registration number -Service
date and licensee signature and license number -A list of services performed -Type
of service - either general service or a correction of conditions
Question 9: What does an inspection label show? What color is it?
Answer:
It shows that an inspection or test has taken place. It must be blue.
Question 10: What seven things must an inspection label say?
Answer:
DO NOT REMOVE BY ORDER OF THE TEXAS FIRE MARSHALL
INSPECTION/TEST RECORD -The firm's name address telephone and
registration number -INSPECTION date and licensee signature and license
number -Type of inspection - new install, Semi annual, quarterly or annual -Date of
last sensitivity test -Status of the system after inspection, and whether a red or
yellow label was attached
Question 11: When should a yellow label be used?
Answer:
If a system does not meet applicable codes and standards
, Question 12: What must happen if a yellow label is attached?
Answer:
The property owner and local jurisdiction must be informed in writing within five
days of the label being attached
Question 13: What five things must be listed on a yellow label?
Answer:
DO NOT REMOVE BY ORDER OF THE FIRE MARSHALL SYSTEM DOES NOT
COMPLY WITH APPLICABLE CODES AND STANDARDS -The firms
name.address, telephone and registration number -Date label was attached and
licensee signature and number a list of conditions resulting in the yellow label
Question 14: Where should a yellow or red label be attached?
Answer:
On the outside of the control panel or in a permanent location
Question 15: When should a red label be attached?
Answer:
If a system does not function or is inoperable
Question 16: What must happen after a red label is attached?
Answer:
The property owner or occupant must be orally notified immediately. The property
owner and local jurisdiction must be informed in writing within 5 days of the label
being attached.
Question 17: What five things must be on a red label?
Answer:
DO NOT REMOVE BY ORDER OF THE FIRE MARSHALL -Status of the system -
inoperable, impaired, or fault -The firms name, address, telephone and registration
number -Date label was attached and licensee signature and license number -A list
of conditions resulting in the red label
Question 18: What does P.L.F.A stand for?
QUESTIONS AND DETAILED SOLUTIONS LATEST UPDATE THIS
YEAR JUST RELEASED
Question 1: When must the three installation inspections be
performed?
Answer:
1- At the completion of the device back box but prior to #2 - 2- At the completion of
the device cable installation but prior to #3 - 3- At the completion of the device
installation but prior to activation
Question 2: What is the purpose of fire alarm plans and record
drawings tag?
Answer:
To certify that the plan or finished drawing of a fire system meets all codes and
standards
Question 3: What five things should it say on the installation label?
Answer:
DO NOT REMOVE BY ORDER OF THE TEXAS FIRE MARSHALL
-INSTALLATION RECORD -The firms name address telephone and registration
number -Installation date and licensee signature and license number -The name of
whoever planned the system
Question 4: What five things should it say on the RESIDENTIAL
installation label?
Answer:
DO NOT REMOVE BY ORDER OF THE TEXAS FIRE MARSHALL
INSTALLATION RECORD -The firm's name address telephone and registration
number -Installation date and licensee signature and license number -An
inscription certifying the install meets code
Question 5: When and where must the installation labels be
placed?
,Answer:
Inside the control panel cover or in a permanent location
Question 6: When must a service label be used?
Answer:
After any service that has corrected and issue that was noted on a yellow or red
label
Question 7: How long must a service label stay in place?
Answer:
Two years. An agent of the Fire Marshall may remove it at any time.
Question 8: What six things must be listed on a Service Label?
Answer:
DO NOT REMOVE BY ORDER OF THE TEXAS FIRE MARSHALL SERVICE
RECORD -The firm's name address telephone and registration number -Service
date and licensee signature and license number -A list of services performed -Type
of service - either general service or a correction of conditions
Question 9: What does an inspection label show? What color is it?
Answer:
It shows that an inspection or test has taken place. It must be blue.
Question 10: What seven things must an inspection label say?
Answer:
DO NOT REMOVE BY ORDER OF THE TEXAS FIRE MARSHALL
INSPECTION/TEST RECORD -The firm's name address telephone and
registration number -INSPECTION date and licensee signature and license
number -Type of inspection - new install, Semi annual, quarterly or annual -Date of
last sensitivity test -Status of the system after inspection, and whether a red or
yellow label was attached
Question 11: When should a yellow label be used?
Answer:
If a system does not meet applicable codes and standards
, Question 12: What must happen if a yellow label is attached?
Answer:
The property owner and local jurisdiction must be informed in writing within five
days of the label being attached
Question 13: What five things must be listed on a yellow label?
Answer:
DO NOT REMOVE BY ORDER OF THE FIRE MARSHALL SYSTEM DOES NOT
COMPLY WITH APPLICABLE CODES AND STANDARDS -The firms
name.address, telephone and registration number -Date label was attached and
licensee signature and number a list of conditions resulting in the yellow label
Question 14: Where should a yellow or red label be attached?
Answer:
On the outside of the control panel or in a permanent location
Question 15: When should a red label be attached?
Answer:
If a system does not function or is inoperable
Question 16: What must happen after a red label is attached?
Answer:
The property owner or occupant must be orally notified immediately. The property
owner and local jurisdiction must be informed in writing within 5 days of the label
being attached.
Question 17: What five things must be on a red label?
Answer:
DO NOT REMOVE BY ORDER OF THE FIRE MARSHALL -Status of the system -
inoperable, impaired, or fault -The firms name, address, telephone and registration
number -Date label was attached and licensee signature and license number -A list
of conditions resulting in the red label
Question 18: What does P.L.F.A stand for?